
token = '16604e967d52281868a18b0300670a43'

def params(repo, username, token, import_url):
    return {
        'utf8': '✓',
        'authenticity_token': token,
        'project[name]': repo,
        'project[namespace_path]': username,
        'project[path]': repo,
        'project[public]': '1',
        'language': '0',
        'ignore': 'no',
        'license': 'no',
        'model': '1',
        'prod': 'master',
        'dev': 'develop',
        'feat': 'feature',
        'rel': 'release',
        'bugfix': 'hotfix',
        'project[import_url]': import_url
    }



'''
example
'''

from git2gitee.cross import Cross
from git2gitee.config import token


if __name__ == '__main__':
    gee = Cross(token, 'toyourheart163/seeing')
    gee.import_to_gitee()
    gee.clone()
    gee.rename_config_repo_url()



'''
从github导入仓库到gitee
解决github下载速度慢的问题
'''

import sys
from argparse import ArgumentParser

from git2gitee.cross import Cross
from git2gitee.config import token


__author__ = 'wei40680@gmail.com'
__version__ = '0.0.4'
my_gitee = 'https://gitee.com/mikele'


def cmd():
    ap = ArgumentParser(description='fork github repo to gitee. then clone to local.')
    ap.add_argument(dest='repo', metavar='repo')
    ap.add_argument('-u', '--username', action='store', default='mikele', help='gitee username')
    ap.add_argument('-s', '--seconds', action='store', default=180)
    ap.add_argument('-t', '--token', action='store', help='gitee api token', default=token)
    ap.add_argument('-c', '--clone', action='store_true')
    args = ap.parse_args()
    gee = Cross(args.token, args.repo, args.username, timeout=args.seconds)
    gee.import_to_gitee()
    if args.clone:
        gee.clone()
        gee.rename_config_repo_url()


if __name__ == '__main__':
    cmd()



'''
import to gitee, clone to local, rename config url
'''
import os
import re
import requests
import sys
import time

from git2gitee.config import params, token


class Cross:
    '''
    :params username: gitee username
    :params repo: github repo
    :params token: gitee api token
    '''
    def __init__(self, token, repo, username='mikele', timeout=180):
        self.username = username
        self.token = token
        self.repo = repo
        self.repo_name = self.repo.split('/')[-1:][0]
        self.timeout = timeout
        self.sess = requests.Session()
        self.headers={'Authorization': 'Token ' + token}

    def valib_repo_url(self) -> str:
        '''return repo url'''
        protocols = ('git', 'https')
        github_base_url = 'https://github.com/'
        if self.repo.startswith(github_base_url):
            return self.repo
        else:
            return github_base_url + self.repo

    def import_to_gitee(self):
        '''fetch github url to gitee'''
        url = self.import_url = self.valib_repo_url()
        form = params(self.repo_name, self.username, self.token, url)
        print('开始导入')
        r = self.sess.post(url, data=form, headers=self.headers, timeout=2)
        if r.status_code == 200:
            timeout = int(self.timeout)
            while not self.check_fetch():
                sys.stdout.write('\r正在导入, 请先等待>>> {}秒'.format(timeout))
                timeout -= 10
                time.sleep(10)

    def check_fetch(self):
        # 检查是否导入成功
        self.gitee_url = 'https://gitee.com/{}/{}'.format(self.username, self.repo_name)
        gitee_url_check = self.gitee_url + '/{name}/check_fetch'.format(name=self.repo_name)
        r = self.sess.get(gitee_url_check)
        return False if r['in_fetch'] == 'false' else True

    def clone(self):
        # clone 到本地
        os.system('git clone ' + self.valib_repo_url())

    def rename_config_repo_url(self):
        # 修改本地的git remote -v 为 import_url 的地址
        config = os.path.join(self.repo_name, '.git', 'config')
        with open(config, 'r+') as f:
            gitee_config = f.read()
            github_config = gitee_config.replace(self.gitee_url, self.import_url)
            f.write(github_config)
            print('game over')

    def force_sync_github(self) -> int:
        '''
        force sync import url
        return:
            status -> 1
        '''
        params = {
            "user_sync_code": '',
            "password_sync_code": '',
            "sync_wiki": "false",
            "authenticity_token": self.token
        }
        url = self.valib_repo_url() + '/force_sync_project'
        r = self.sess.post(url, data=params, headers=self.headers)
        return r.json()['status']



import setuptools

from git2gitee import __version__

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="git2gitee",
    version=__version__,
    author="Mikele",
    author_email="blive200@gmail.com",
    description="import github repo to gitee, then clone to local",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/toyourheart163/git2gitee",
    packages=setuptools.find_packages(),
    install_requires=['requests'],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    entry_points={
        'console_scripts': ['git2gitee = git2gitee:cmd']
    },
    python_requires='>=3.6',
)
